summaryrefslogtreecommitdiffstats
path: root/mandoc.h
diff options
context:
space:
mode:
authorIngo Schwarze <schwarze@openbsd.org>2014-07-04 01:50:06 +0000
committerIngo Schwarze <schwarze@openbsd.org>2014-07-04 01:50:06 +0000
commit604a31609737053378ee534fa32241da4a8500bf (patch)
treebb0d4899153946ca0e4cda89b64b10aa5122b23c /mandoc.h
parentd34c8b8f2efbf5e05c8603d4ea4f46f0b338661a (diff)
downloadmandoc-604a31609737053378ee534fa32241da4a8500bf.tar.gz
Clean up messages related to missing arguments.
* Do not warn about empty -column cells, they seem valid to me. * Downgrade empty item and missing -std from ERROR to WARNING. * Hierarchical naming. * Descriptive, not imperative style. * Mention macro names, argument names, and fallbacks. * Garbage collect some unreachable code in post_it().
Diffstat (limited to 'mandoc.h')
-rw-r--r--mandoc.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/mandoc.h b/mandoc.h
index 58f6f644..b2a0f802 100644
--- a/mandoc.h
+++ b/mandoc.h
@@ -88,11 +88,13 @@ enum mandocerr {
MANDOCERR_COND_EMPTY, /* conditional request controls empty scope */
MANDOCERR_MACRO_EMPTY, /* skipping empty macro: macro */
MANDOCERR_ARGCWARN, /* argument count wrong */
- MANDOCERR_DISPTYPE, /* missing display type */
- MANDOCERR_LISTFIRST, /* list type must come first */
- MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
- MANDOCERR_IT_NOHEAD, /* missing head in list item: type */
+ MANDOCERR_BD_NOTYPE, /* missing display type, using -ragged */
+ MANDOCERR_BL_LATETYPE, /* list type is not the first argument: arg */
+ MANDOCERR_BL_WIDTH, /* missing -width in -tag list, using 8n */
+ MANDOCERR_IT_NOHEAD, /* empty head in list item: type */
+ MANDOCERR_IT_NOBODY, /* empty list item: type */
MANDOCERR_FONTTYPE, /* missing font type */
+ MANDOCERR_ARG_STD, /* missing -std argument, adding it: macro */
/* related to bad macro arguments */
MANDOCERR_IGNARGV, /* skipping argument */
@@ -146,11 +148,8 @@ enum mandocerr {
MANDOCERR_SCOPEBROKEN, /* missing end of block */
MANDOCERR_SCOPEEXIT, /* scope open on exit */
MANDOCERR_UNAME, /* uname(3) system call failed */
- /* FIXME: merge following with MANDOCERR_ARGCOUNT */
- MANDOCERR_NOBODY, /* macro requires body argument(s) */
- MANDOCERR_NOARGV, /* macro requires argument(s) */
MANDOCERR_NUMERIC, /* request requires a numeric argument */
- MANDOCERR_LISTTYPE, /* missing list type */
+ MANDOCERR_BL_NOTYPE, /* missing list type, using -item */
MANDOCERR_ARGSLOST, /* line argument(s) will be lost */
MANDOCERR_FATAL, /* ===== start of fatal errors ===== */